from django.db import models
from django.core.validators import MinValueValidator
from .servizio import Servizio


class Articolo(models.Model):
    servizio = models.ForeignKey(
        Servizio,
        on_delete=models.SET_NULL,
        null=True,
    )
    nome = models.CharField(max_length=255)
    slug = models.SlugField(unique=True)
    prezzo = models.DecimalField(
        blank=False,
        null=False,
        max_digits=19,
        decimal_places=2,
        validators=[MinValueValidator(0.0)],
    )
    prezzo_a_partire = models.BooleanField()
    descrizione = models.TextField(blank=True, null=True)

    def __str__(self):
        return self.nome

    class Meta:
        verbose_name = "Articolo"
        verbose_name_plural = "Articoli"
